<?php

use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

/**
 * Class WC_Gateway_ZondacryptoPay_Blocks_Support
 */
final class WC_Gateway_ZondacryptoPay_Blocks_Support extends AbstractPaymentMethodType
{
    /**
     * Name of the payment method.
     *
     * @var string
     */
    protected $name = 'zondacryptopay';

    public function initialize() {
        $this->settings = get_option( 'woocommerce_zondacryptopay_settings', array() );
    }

    /**
     * Returns if this payment method should be active. If false, the scripts will not be enqueued.
     *
     * @return boolean
     */
    public function is_active() {
        $payment_gateways_class = WC()->payment_gateways();
        $payment_gateways       = $payment_gateways_class->payment_gateways();

        return $payment_gateways['zondacryptopay']->is_available();
    }

    /**
     * Returns an array of scripts/handles to be registered for this payment method.
     *
     * @return array
     */
    public function get_payment_method_script_handles() {
        $version = WOOCOMMERCE_ZONDACRYPTOPAY_VERSION;
        wp_register_script(
            'wc-zondacryptopay-blocks-integration',
            WOOCOMMERCE_ZONDACRYPTOPAY_PLUGIN_URL . '/client/blocks/index.js',
            [],
            $version,
            true
        );
        wp_set_script_translations(
            'wc-zondacryptopay-blocks-integration',
            'zondacryptopay'
        );
        return array( 'wc-zondacryptopay-blocks-integration' );
    }

    /**
     * Returns an array of key=>value pairs of data made available to the payment methods script.
     *
     * @return array
     */
    public function get_payment_method_data() {
        return array(
            'title'       => $this->get_setting( 'zondacryptopay_payment_title' ) ?: 'zondacrypto pay',
            'description' => __('Cryptocurrency payments.', 'zondacryptopay'),
            'supports'    => $this->get_supported_features(),
            'logo_url'    => WOOCOMMERCE_ZONDACRYPTOPAY_PLUGIN_URL . 'resources/images/logo.svg',
        );
    }

    /**
     * Returns an array of supported features.
     *
     * @return string[]
     */
    public function get_supported_features() {
        $payment_gateways = WC()->payment_gateways->payment_gateways();
        return $payment_gateways['zondacryptopay']->supports;
    }
}
