<?php

namespace ZondacryptoPay\Payment;

use Exception;

/**
 * Class Util
 *
 * @package Payment
 */
class Util
{
	const ENVIRONMENT_PRODUCTION = 'production';

	const METHOD_GET = 'GET';
	const METHOD_POST = 'POST';

	const HTTP_CODE_200 = 200;
	const HTTP_CODE_404 = 404;

	public const TRANSACTION_STATUS_COMPLETED = 'COMPLETED';
	public const TRANSACTION_STATUS_ACTION_REQUIRED = 'ACTION_REQUIRED';

    public const AVAILABLE_TRANSACTION_STATUSES = [
        self::TRANSACTION_STATUS_COMPLETED,
        self::TRANSACTION_STATUS_ACTION_REQUIRED,
    ];

	/**
	 * If in future will appear one of CLF, UYW, BHD, IQD, JOD, KWD, LYD, OMR, TND currency - Module must be modified!!!
	 *
	 * @var array
	 */
	private static $supportedCurrencies = [
		'pln' => 'PLN',
		'eur' => 'EUR',
		'usd' => 'USD',
		'gbp' => 'GBP',
	];

	/**
	 * @return string
	 * @throws Exception
	 */
	public static function generateUuidV4()
	{

		return sprintf('%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
			// 32 bits for "time_low"
			mt_rand(0, 0xffff), mt_rand(0, 0xffff),

			// 16 bits for "time_mid"
			mt_rand(0, 0xffff),

			// 16 bits for "time_hi_and_version",
			// four most significant bits holds version number 4
			mt_rand(0, 0x0fff) | 0x4000,

			// 16 bits, 8 bits for "clk_seq_hi_res",
			// 8 bits for "clk_seq_low",
			// two most significant bits holds zero and one for variant DCE1.1
			mt_rand(0, 0x3fff) | 0x8000,

			// 48 bits for "node"
			mt_rand(0, 0xffff), mt_rand(0, 0xffff), mt_rand(0, 0xffff)
		);
	}

	/**
	 * Functions that return true when passed currency is on supported currencies list.
	 *
	 * @param string $currencyCode ISO4217
	 *
	 * @return bool
	 */
	public static function canUseForCurrency($currencyCode)
	{
		return isset(self::$supportedCurrencies[strtolower($currencyCode)]);
	}

	/**
	 * @return string
	 */
	public static function getServiceUrl()
	{
		$url = Configuration::getServiceUrl(Util::ENVIRONMENT_PRODUCTION);

		if($url === false) {
			return '';
		}

		return $url . Configuration::ROUTE_PAYMENTS;
	}

	/**
	 * @param string $variable
	 *
	 * @return bool
	 */
	public static function isJson($variable)
	{
		json_decode($variable);

		return (json_last_error() === JSON_ERROR_NONE);
	}

	public static function getSupportedCurrencies(): array
	{
		return self::$supportedCurrencies;
	}
}
